ConsumedEntry

Struct ConsumedEntry 

pub struct ConsumedEntry {
    pub token_id: String,
    pub redeemed_at: DateTime<Utc>,
    pub expires_at: Option<DateTime<Utc>>,
}
A single consumed token entry.

Fields

token_id: Stringredeemed_at: DateTime<Utc>expires_at: Option<DateTime<Utc>>

Token expiry captured from the DelegationClaims. Entries with expires_at in the past can be GC’d because the expiry check would reject the replay before the consumed check is reached. For tokens issued without expiry, this is None and the entry is kept indefinitely.