pub fn create_session(
keypair: &IdentityKeypair,
member: &str,
project_id: &str,
ttl: Option<Duration>,
) -> SessionTokenExpand description
Create a session token signed by the identity keypair.
pub fn create_session(
keypair: &IdentityKeypair,
member: &str,
project_id: &str,
ttl: Option<Duration>,
) -> SessionTokenCreate a session token signed by the identity keypair.