Guard

Struct Guard 

pub struct Guard { /* private fields */ }
Centralized runtime validation for the Trust Model.

Implementations

Source

impl Guard

pub fn new(project: &Project) -> Self

Create a Guard from a loaded project (no gates).

pub fn with_gates( project: &Project, gates: BTreeMap<String, GateConfig>, ) -> Self

Create a Guard with gates.

pub fn load(root: &Path) -> Result<Self, JoyError>

Load project.yaml and create a Guard, including gate config.

pub fn gates(&self) -> &BTreeMap<String, GateConfig>

Get the configured gates (for display in joy project).

pub fn check(&self, action: &Action, identity: &Identity) -> Verdict

Check whether an action is allowed for the given identity.

pub fn is_last_manager(&self, member_id: &str) -> bool

Check if removing a member would leave no one with manage capability.