Centralized runtime validation for Joy’s Trust Model.
Guard intercepts write operations and checks them against the project’s member capabilities. It is the enforcement point for the Guardianship pillar of AI Governance (ADR-021).
Guard is zero-overhead for simple setups: when no members are configured,
or when the acting member has capabilities: all, checks return Allow
without capability mapping.
Structs
- Gate
Config - Configuration for a single transition gate.
- Guard
- Centralized runtime validation for the Trust Model.
Enums
Functions
- enforce
- One-shot guard check: resolve identity from session, check, enforce.
- status_
str - Convert Status to the string used in gate config keys.