pub struct Guard { /* private fields */ }Expand description
Centralized runtime validation for the Trust Model.
Implementations
Sourceimpl Guard
impl Guard
Sourcepub fn with_gates(
project: &Project,
gates: BTreeMap<String, GateConfig>,
) -> Self
pub fn with_gates( project: &Project, gates: BTreeMap<String, GateConfig>, ) -> Self
Create a Guard with gates.
Sourcepub fn load(root: &Path) -> Result<Self, JoyError>
pub fn load(root: &Path) -> Result<Self, JoyError>
Load project.yaml and create a Guard, including gate config.
Sourcepub fn gates(&self) -> &BTreeMap<String, GateConfig>
pub fn gates(&self) -> &BTreeMap<String, GateConfig>
Get the configured gates (for display in joy project).
Sourcepub fn check(&self, action: &Action, identity: &Identity) -> Verdict
pub fn check(&self, action: &Action, identity: &Identity) -> Verdict
Check whether an action is allowed for the given identity.
Sourcepub fn is_last_manager(&self, member_id: &str) -> bool
pub fn is_last_manager(&self, member_id: &str) -> bool
Check if removing a member would leave no one with manage capability.