Configurable paths to the project’s reference documentation, relative to
the project root. Used by joy ai init to support existing repos with
non-default doc layouts and read by AI tools via joy project get docs.<key>.
Derive an acronym from a project name.
Takes the first letter of each word, uppercase, max 4 characters.
Single words use up to 3 uppercase characters.